/*#include <gdk/gdk.h>*/
#include <jack/jack.h>

typedef struct _jack_info{
	char		*name;
	jack_client_t 	*client;	
	long 		samplerate;
	int 		freewheeling;
	int		suspend_playing;
	int		suspend_recording;
	int		alive;
	long		xruns; 	
	float		load;
} jack_info_t;

jack_info_t* mixer_launch (speciallist_t *looperlist);
void mixer_close(jack_info_t *jinfo);
